PyScopus is a Python wrapper for Scopus API: http://dev.elsevier.com/index.html

** Updates on 12/28/2017

- Improve: Compatible with Python 3.6 and fixed bugs on imports

** Updates on 09/07/2017

- Improve: An authorized API key is used for debugging.

- Website updated.

** Updates on 02/13/2017

- Added 'search()'; (originally added in Dec. 2016)

** Updates on 10/04/2016

- Added 'retrieve_abstract()'

- Removed 'search_abstract()'

- Improved: 1) Allow users to save xml files for both abstract and author retrieval xml files; 2) Display unicodes when searching, instead of ignoring and force them into ascii encoding.

** Updates on 09/14/2016

- Add function for searching publications in a venue 

  This can help users retrieve publication information from a specific venue within a specific year range.

** Updates on 04/07/2016

- Add Citation Overview API!!

  This can help retrieve annual citation counts over a specified year range.
  Please note that this requires special authorization.
